import { EndPoints, getData } from "../services/AccessAPI";
import { useNavigate } from "react-router-dom";
import { useEffect } from "react";
import { useState } from 'react';
import { useLocation } from 'react-router-dom';
import { Routes } from "../services/Routes";
import { Collapse } from "reactstrap";
import { AiFillCheckCircle, AiFillPauseCircle } from "react-icons/ai";
import RowButton from "../ui-elements/table/RowButton";
import DataFormatter, { RenderType } from "../ui-elements/table/DataFormatter";
import TranactionTable from "../ui-elements/table/TransactionTable";
import EditButton from "../ui-elements/controls/buttons/EditButton";
import DeleteButton from "../ui-elements/controls/buttons/DeleteButton";
import ExecuteButton from "../ui-elements/controls/buttons/ExecuteButton";
import AddButton from "../ui-elements/controls/buttons/AddButton";
import RefreshButton from "../ui-elements/controls/buttons/RefreshButton";

export default function IntegrationDashboard() {
    const search = useLocation().search;
    const id = new URLSearchParams(search).get('id')

    useEffect(() => {
        getData(EndPoints.INTEGRATIONS + "/" + id).then(
            (result) => {
                if (result) {
                    setIntegration({
                        name: result.name,
                        version: result.version,
                        apiUrl: result.apiUrl,
                        createdOn: result.createdOn,
                        type: result.type,
                        loading: true
                    });
                }
            }
        );

        //getAllTransactionsData();
        healthCheck(id);
        getAllIntegrationAccountsData(id);
        getAllAccountsData();
        //getIntegrationEnvelopeData();
        //getIntegrationAutoclassRulesData(id);
        //getIntegrationHistorical(id, 12);
    }, [id])

    let navigate = useNavigate();

    const [loading, setLoading] = useState(true);

    const [integrationAccounts, setIntegrationAccounts] = useState([]);
    const [accounts, setAccounts] = useState([]);
    const [health, setHealth] = useState({});
    
    const [integration, setIntegration] = useState({
        name: '',
        version: '',
        apiUrl: '',
        createdOn: '',
        type: '',
        loading: true
    });

    function getAllIntegrationAccountsData(id) {
        getData(EndPoints.INTEGRATIONS_ACCOUNTS + "?integration_id=" + id).then(
            (result) => {
                if (result) {
                    setIntegrationAccounts(result);
                    setLoading(false);
                }
            }
        );
    }

    function getAllAccountsData() {
        getData(EndPoints.ACCOUNTS).then(
            (result) => {
                if (result) {
                    setAccounts(result);
                    setLoading(false);
                }
            }
        );
    }

    /*function triggerAutoclassRule(id) {
        getData(EndPoints.AUTOCLASS_TRIGGERAUTOCLASSRULE + "/" + id).then(
            (result) => {
                if (result) {
                    setAutoclassRuleTriggerMessage(result.message);
                    setLoading(false);
                }
            }
        );
    }

    function renderTransactionsTable() {
        return (
            <TranactionTable 
                transactions={transactions} 
                setTransactions={setTransactions}
                referenceIntegrationId={id}
                signedAmount={true}
            />
        );
    }*/

    function findAccountName(id) {
        let name = accounts?.find(x => x.id === id)?.name;
        return name;
    }

    function truncate(data, n) {
        if (data !== null && data !== undefined)
            return (data.length > n) ? data.slice(0, n-1) : data;
        else
            return "";
    };

    function renderIntegrationAccountsTable() {
        return (
            <table className="table table-sm table-striped">
                <thead>
                    <tr>
                        <th>Enabled</th>
                        <th>Name</th>
                        {/*<th>Linked Account</th>*/}
                        <th>Run Interval</th>
                        <th>Last Run</th>
                        <th>Created On</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    {
                        integrationAccounts.map(acc => (
                            <tr key={acc.id}>
                                <td><DataFormatter data={acc.enabled ? <AiFillCheckCircle /> : <AiFillPauseCircle />} /></td>
                                <td><DataFormatter data={acc.name} /></td>
                                {/*<td><DataFormatter data={truncate(findAccountName(acc.linkedAccountId), 20)} /></td>*/}
                                <td><DataFormatter data={acc.runInterval} /></td>
                                <td><DataFormatter data={acc.lastRun} /></td>
                                <td><DataFormatter data={acc.createdOn} /></td>
                                <td>
                                    <EditButton
                                        className="btn btn-sm btn-primary"
                                        onClick={() => navigate(Routes.INTEGRATIONS_ACCOUNTS_EDIT + "?id=" + acc.id)}
                                    />
                                    &nbsp;
                                    <DeleteButton
                                        className="btn btn-sm btn-danger"
                                        onClick={() => navigate(Routes.INTEGRATIONS_ACCOUNTS_DELETE + "?id=" + acc.id)}
                                    />
                                </td>
                            </tr>
                        ))
                    }
                </tbody>
            </table>
        );
    }

    /*function getRuleColor(enabled) {
        return enabled ? "#abfcae" : "fcabad";
    }*/

    /*function renderAutoclassTable() {
        return (
            <div className="row">
                <div className="container-fluid">
                    {
                        autoclassRules.map(rule => (
                            <>
                                <div className="row" style={{backgroundColor: getRuleColor(rule.enabled)}}>
                                    <div className="col-6">
                                        <strong>{rule.name}</strong>
                                    </div>
                                    <div className="col-6">
                                        {rule.enabled ? "Enabled" : "Disabled"}
                                        &nbsp;
                                        &nbsp;
                                        <EditButton
                                            className="btn btn-sm btn-primary"
                                            onClick={() => navigate(Routes.AUTOCLASS_EDIT + "?id=" + rule.id)}
                                        />
                                        &nbsp;
                                        <DeleteButton
                                            className="btn btn-sm btn-danger"
                                            onClick={() => navigate(Routes.AUTOCLASS_DELETE + "?id=" + rule.id)}
                                        />
                                        &nbsp;
                                        <ExecuteButton
                                            className="btn btn-sm btn-warning"
                                            onClick={() => triggerAutoclassRule(rule.id)}
                                        />

                                        <span>{autoclassRuleTriggerMessage}</span>
                                    </div>
                                </div>
                                <div className="row">
                                    <div className="col-6 text-center">If...</div>
                                    <div className="col-6 text-center">...then:</div>
                                </div>
                                <div className="row">
                                    <div className="col-6 text-center">
                                        {
                                            rule.expressions.map(exp => (
                                                <>
                                                    <div className="row">
                                                        <div className="col-12 text-center">
                                                            {exp.transactionField} is {exp.compareOperator} {exp.value}
                                                        </div>
                                                    </div>
                                                </>
                                            ))
                                        }
                                    </div>
                                    <div className="col-6 text-center">
                                        {
                                            rule.changes.map(chg => (
                                                <>
                                                    <div className="row">
                                                        <div className="col-12 text-center">
                                                            {chg.field} is set to "{chg.value}"
                                                        </div>
                                                    </div>
                                                </>
                                            ))
                                        }
                                    </div>
                                </div>
                            </>
                        ))
                    }
                </div>
            </div>
        );
    }*/

    /*function medianIncome()
    {
        if (integrationHistorical.income === null || integrationHistorical.income === undefined )
            return 0;

        return integrationHistorical.income.median;
    }*/

    /*let transactionsContent = loading ? (
        <p>
            <em>Loading...</em>
        </p>
    ) : (renderTransactionsTable())*/

    function healthCheck(id) {
        getData(EndPoints.INTEGRATIONS_HEALTHCHECK + "/" + id).then(
            (result) => {
                if (result) {
                    setHealth(result);
                    setLoading(false);
                }
            }
        );
    }

    let integrationAccountsContent = loading ? (
        <p>
            <em>Loading...</em>
        </p>
    ) : (renderIntegrationAccountsTable())

    /*let autoclassContent = loading ? (
        <p>
            <em>Loading...</em>
        </p>
    ) : (renderAutoclassTable())*/

    return (
        <div>
            <h2>{integration.name}
                &nbsp;
                <EditButton
                    className="btn btn-sm btn-primary"
                    onClick={() => navigate(Routes.INTEGRATIONS_EDIT + "?id=" + id)}
                />
                &nbsp;
                <DeleteButton
                    className="btn btn-sm btn-danger"
                    onClick={() => navigate(Routes.INTEGRATIONS_DELETE + "?id=" + id)}
                />
                &nbsp;
                <RefreshButton
                    className="btn btn-sm btn-warning"
                    onClick={() => healthCheck(id)}
                />
            </h2>
            
            <div className="container-fluid">
                <div className="row">
                    <div className="col-md-6">
                        <h5>API Url: <DataFormatter data={integration.apiUrl} /></h5>
                        <h5>Type: <DataFormatter data={integration.type} /></h5>
                        <h5>Version: <DataFormatter data={integration.version} /></h5>
                        <h5>Created on: <DataFormatter data={integration.createdOn} renderType={RenderType.Date} /></h5>
                    </div>
                    <div className="col-md-6">
                        <h4><DataFormatter data={health && health.isHealthy ? "Healthy" : "Unhealthy"} /></h4>
                    </div>
                </div>
                <hr />
                {/*<div className="row">
                    <div className="text-center">
                        <h5 className="">
                            {
                                autoclassRules?.length > 0 ?
                                    <button onClick={toggleAutoClassDialog} className="btn btn-sm btn-outline-primary">{isAutoclassOpen ? "Hide " + autoclassRules?.length + " Autoclass Rules" : "Show " + autoclassRules?.length + " Autoclass Rules"}</button>
                                    : null
                            }
                            
                            &nbsp;
                            
                            <button onClick={() => navigate(Routes.AUTOCLASS_CREATE)} className="btn btn-sm btn-outline-primary">Create Autoclass Rule</button>
                        </h5>
                    </div>
                </div>
                <div className="row">
                    <Collapse isOpen={isAutoclassOpen}>
                        {autoclassContent}
                    </Collapse>
                </div>*/}
                <div className="row">
                    <div className="col-md-12">
                        <div className="row">
                            <div className="text-center">
                                <h3 className="">
                                    Integration Accounts
                                    &nbsp;
                                    <AddButton
                                        className="btn btn-sm btn-primary"
                                        onClick={() => navigate(Routes.INTEGRATIONS_ACCOUNTS_CREATE + "?id=" + id)}
                                    />
                                </h3>
                            </div>
                        </div>
                        {integrationAccountsContent}
                    </div>
                </div>
                {/*<div className="row">
                    <div className="col-md-12">
                        <div className="row">
                            <div className="text-center">
                                <h3 className="">
                                    Transactions
                                    &nbsp;
                                    <AddButton
                                        className="btn btn-sm btn-primary"
                                        onClick={() => navigate(Routes.TRANSACTIONS_CREATE)}
                                    />
                                </h3>
                            </div>
                        </div>
                        {transactionsContent}
                    </div>
                </div>*/}
            </div>
        </div>
    );
}