import { EndPoints, getData } from "../services/AccessAPI";
import { useNavigate } from "react-router-dom";
import { useEffect } from "react";
import { useState } from 'react';
import { Routes } from "../services/Routes";
import RowButton from "../ui-elements/table/RowButton";
import DataFormatter, { RenderType } from "../ui-elements/table/DataFormatter";
import EditButton from "../ui-elements/controls/buttons/EditButton";
import DeleteButton from "../ui-elements/controls/buttons/DeleteButton";
import RefreshButton from "../ui-elements/controls/buttons/RefreshButton";

export default function Integrations() {
    useEffect(() => {
        getAllIntegrationsData();
        //getAllUsersData();
    }, [])

    let navigate = useNavigate();

    const [state, setState] = useState({
        integrations: [],
        loading: false
    });

    const [users, setUsers] = useState(null);

    function onIntegrationCreate() {
        navigate(Routes.INTEGRATIONS_CREATE);
    }

    function onIntegrationDashboard(id) {
        let query = "?id=" + id
        navigate(Routes.INTEGRATIONS_DASHBOARD + query);
    }

    function onIntegrationEdit(id) {
        let query = "?id=" + id
        navigate(Routes.INTEGRATIONS_EDIT + query);
    }

    function onIntegrationDelete(id) {
        let query = "?id=" + id
        navigate(Routes.INTEGRATIONS_DELETE + query);
    }

    function getAllIntegrationsData() {
        getData(EndPoints.INTEGRATIONS).then(
            (result) => {
                if (result) {
                    setState({
                        integrations: result,
                        loading: false
                    });
                }
            }
        );
    }

    function getAllUsersData() {
        getData(EndPoints.USERS).then(
            (result) => {
                if (result) {
                    setUsers(result);
                }
            }
        );
    }

    /*function refreshIntegration(id) {
        getData(EndPoints.ACCOUNTS_REFRESHBALANCE + "/" + id).then(
            (result) => {
                if (result) {
                    getAllIntegrationsData();
                }
            }
        );
    }*/

    function findUserName(id) {
        return users?.find(x => x.id)?.username;
    }

    function renderAllIntegrationsTable(integrations) {
        return (
            <div className="container-fluid">
                <div className="row">
                    <div className="col-md-12">
                        <table className="table table-sm table-striped">
                            <thead>
                                <tr>
                                    <th>Name</th>
                                    <th>Type</th>
                                    <th>Version</th>
                                    <th>API Url</th>
                                    <th>Created On</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                {
                                    integrations.map(integration => (
                                        <tr key={integration.id}>
                                            <td><button className="btn btn-sm btn-clear" onClick={() => onIntegrationDashboard(integration.id)}><DataFormatter data={integration.name} /></button></td>
                                            <td><DataFormatter data={integration.type} /></td>
                                            <td><DataFormatter data={integration.version} /></td>
                                            <td><DataFormatter data={integration.apiUrl} /></td>
                                            <td><DataFormatter data={integration.createdOn} renderType={RenderType.Date} /></td>
                                            <td>
                                                <EditButton
                                                    className="btn btn-sm btn-primary"
                                                    onClick={() => onIntegrationEdit(integration.id)}
                                                />
                                                &nbsp;
                                                <DeleteButton
                                                    className="btn btn-sm btn-danger"
                                                    onClick={() => onIntegrationDelete(integration.id)}
                                                />
                                                &nbsp;{/*
                                                <RefreshButton
                                                    className="btn btn-sm btn-warning"
                                                    onClick={() => refreshIntegration(integration.id)}
                                                />*/}
                                            </td>
                                        </tr>
                                    ))
                                }
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        );
    }

    let content = state.loading ? (
        <p>
            <em>Loading...</em>
        </p>
    ) : (
        renderAllIntegrationsTable(state.integrations)
    )

    
    return (
        <div>
            <h3>List of Integrations</h3>
            <button onClick={() => onIntegrationCreate()} className="btn btn-primary">Register new integration</button>
            {content}
        </div>
    );
}