import { EndPoints, getData, putData } from "../services/AccessAPI";
import { useNavigate, useLocation } from "react-router-dom";
import { useEffect } from "react";
import { useState } from 'react';
import { Routes } from "../services/Routes";
import TextInput from "../ui-elements/controls/input/TextInput";

export default function UpdateIntegration() {
    let navigate = useNavigate();
    const search = useLocation().search;
    const id = new URLSearchParams(search).get('id')

    const [name, setName] = useState("");
    const [apiUrl, setApiUrl] = useState("");
    const [type, setType] = useState("");
    const [loading, setLoading] = useState(false);

    useEffect(() => {
        getData(EndPoints.INTEGRATIONS + "/" + id).then(
            (result) => {
                if (result) {
                    setName(result.name);
                    setApiUrl(result.apiUrl);
                    setType(result.type);
                    setLoading(false);
                }
            }
        );
    }, [id])

    function onKeyDown(e) {
        if (e.key === 'Enter') {
            this.update(false);
        }
    }
    
    function onUpdateCancel() {
        navigate(Routes.INTEGRATIONS);
    }

    function onSubmit(e) {
        e.preventDefault();

        let integrationProfile = {
            name: name,
            apiUrl: apiUrl,
            type: type,
        }

        putData(EndPoints.INTEGRATIONS + "/" + id, integrationProfile).then((result) => {
                let responseJson = result;
                
                if (responseJson) {
                    console.log(responseJson);
                    navigate(Routes.INTEGRATIONS);
                }
            }
        );
    }

    return(
        <div className="row">
            <div className="col-md-4">
                <h3>Edit Integration</h3>
                <form onSubmit={onSubmit}>
                    <div className="form-group">
                        <label className="control-label">Integration Name: </label>
                        <TextInput
                            className="form-control"
                            value={name}
                            onChange={(e) => setName(e.target.value)}
                            name="name"
                            onKeyDown={onKeyDown}
                        />
                    </div>

                    <br />
                    <div className="form-group">
                        <label className="control-label">API Url: </label>
                        <TextInput
                            className="form-control"
                            value={apiUrl}
                            onChange={(e) => setApiUrl(e.target.value)}
                            name="apiUrl"
                            onKeyDown={onKeyDown}
                        />
                    </div>

                    <br />
                    <div className="form-group">
                        <label className="control-label">Type: </label>
                        <TextInput
                            className="form-control"
                            value={type}
                            onChange={(e) => setType(e.target.value)}
                            name="type"
                            onKeyDown={onKeyDown}
                        />
                    </div>

                    <br />
                    <div className="form-group">
                        <button onClick={onUpdateCancel} className="btn btn-primary">Cancel</button>
                        &nbsp;&nbsp;
                        <input type="submit" value="Edit" className="btn btn-warning"></input>
                    </div>
                </form>
            </div>
        </div>
    );
}