using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using ActiveAllocator.API.Configs;
using ActiveAllocator.API.Entities;
using ActiveAllocator.API.Models.Envelopes;
using ActiveAllocator.API.Models.Transactions;
using ActiveAllocator.API.Services;
using Internal;
using Microsoft.Extensions.Options;

namespace ActiveAllocator.API.Processes;

public class IntegrationProcess : IIntegrationProcess
{
   private readonly IntegrationConfig _config;
   private readonly ILogger<IntegrationProcess> _logger;

   public IntegrationProcess(
        IOptions<IntegrationConfig> config,
        ILogger<IntegrationProcess> logger)
   {
      _config = config.Value;
      _logger = logger;
   }

   public async Task RunTransactionImporterIntegrations(IIntegrationService integrationService)
   {
        _logger.LogInformation($"IntegrationWorker| Running Transaction Importer Integrations...");
         
        // Grab relevant integration accounts
        List<IntegrationAccount> integrationAccounts = integrationService
            .GetAllAccounts()
            .Where(a => a.Integration.Type == Enums.IntegrationType.TransactionImporter)
            .ToList();

        bool anyTriggered = false;
        
        foreach (IntegrationAccount acc in integrationAccounts)
        {
            // Check if needs triggering
            if (acc.Enabled && DateTime.UtcNow.Subtract(acc.LastRun).TotalMinutes >= acc.RunInterval)
            {
                _logger.LogInformation($"IntegrationAccount '{acc.Name}' (id={acc.Id}) is ready for importing - Has now been triggered.");
                anyTriggered = true;

                // Fund Envelope
                await integrationService.RunTransactionImport(acc.Id);
            }
        }

        if (!anyTriggered)
            _logger.LogInformation($"No action taken.");
        else
            _logger.LogInformation($"Transaction Importing complete.");
   }
}
