using System;
using ActiveAllocator.API.Configs;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Options;
using ActiveAllocator.API.Processes;
using ActiveAllocator.API.Services;

namespace ActiveAllocator.API.Workers;

public class IntegrationWorker : BackgroundService
{
   private readonly IntegrationConfig _config;
   private readonly IIntegrationProcess _integrationProcess;
   private readonly ILogger<IntegrationWorker> _logger;
   private readonly IServiceScopeFactory _serviceScopeFactory;

   public IntegrationWorker(IOptions<IntegrationConfig> config, IIntegrationProcess integrationProcess, ILogger<IntegrationWorker> logger, IServiceScopeFactory serviceScopeFactory)
   {
      _config = config.Value;
      _integrationProcess = integrationProcess;
      _logger = logger;
      _serviceScopeFactory = serviceScopeFactory;
   }

   protected override async Task ExecuteAsync(CancellationToken stoppingToken)
   {
      DateTime? lastExecutedOn = null;
      uint minutesBetweenRun = 1;
      
      using (var scope = _serviceScopeFactory.CreateScope())
      {
         IIntegrationService integrationService = scope.ServiceProvider.GetService<IIntegrationService>();

         // This is how we keep the app running (in the background)
         while (!stoppingToken.IsCancellationRequested)
         {
            if (lastExecutedOn != null)
            {
               int minutesRemaining = Math.Abs(_config.CheckIntervalInMinutes - (int)DateTime.UtcNow.Subtract(lastExecutedOn.Value).TotalMinutes);
               await Task.Delay(TimeSpan.FromMinutes(minutesRemaining), stoppingToken);
            }

            lastExecutedOn = DateTime.UtcNow;
            _logger.LogInformation("IntegrationWorker running at: {time}", DateTimeOffset.Now);

            await _integrationProcess.RunTransactionImporterIntegrations(integrationService);
         }
      }
   }
}
